@@ -20,7 +20,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: JadortServiceStatefulBean.java 5667 2009-12-02 10:10:51Z alitokmen $
+ * $Id: JadortServiceStatefulBean.java 5850 2010-01-05 14:50:56Z alitokmen $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jasmine.jadort.service.implementation;
@@ -37,6 +37,8 @@ import java.util.Date;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 
 import javax.annotation.PostConstruct;
 import javax.annotation.PreDestroy;
@@ -77,15 +79,20 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
     // Constants used internally by JadortServiceStatefulBean
     private final static int BUFFER_SIZE = 16384;
 
+    /**
+     * Logger.
+     */
+    private Logger logger = Logger.getLogger(this.getClass().getName());
+
     @PostConstruct
     protected void initialize() {
         try {
             JMSSender.connect();
-        } catch (Exception e) {
-            IllegalStateException exception = new IllegalStateException("Failed initializing a JadortService stateful bean: "
-                + e.getMessage(), e);
-            System.out.println(exception.getMessage());
-            e.printStackTrace();
+        } catch (Throwable t) {
+            final String message = "Failed initializing a JadortService stateful bean: " + t.getMessage();
+            IllegalStateException exception = new IllegalStateException(message, t);
+
+            this.logger.log(Level.SEVERE, message, t);
             throw exception;
         }
     }
@@ -94,11 +101,11 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
     protected void terminate() {
         try {
             JMSSender.disconnect();
-        } catch (Exception e) {
-            IllegalStateException exception = new IllegalStateException("Failed terminating a JadortService stateful bean: "
-                + e.getMessage(), e);
-            System.out.println(exception.getMessage());
-            e.printStackTrace();
+        } catch (Throwable t) {
+            final String message = "Failed terminating a JadortService stateful bean: " + t.getMessage();
+            IllegalStateException exception = new IllegalStateException(message, t);
+
+            this.logger.log(Level.SEVERE, message, t);
             throw exception;
         }
     }
@@ -299,8 +306,7 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
                     }
                 }
                 if (bean.getSelectedGroup() != null) {
-                    if (this.operation.getCurrentStep().equals(Step.SELECT_GROUP)
-                        || this.operation.getCurrentStep().equals(Step.SELECT_APPLICATION)) {
+                    if (this.operation.getCurrentStep().equals(Step.SELECT_APPLICATION)) {
                         this.fillApplications(bean.getSelectedGroup());
                     }
                     if (this.operation.getCurrentStep().equals(Step.SELECT_VM_IMAGE)
@@ -452,6 +458,24 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
 
             for (GroupBean group : this.operation.getTopology().getGroups()) {
                 if (group.getId().equals(selectedGroup.getId())) {
+                    // fillApplications and fillVMImages will check connectivity
+                    this.fillApplications(group);
+                    this.fillVMImages(group);
+
+                    // check connectivity with workers
+                    if (group.getWorkers() != null) {
+                        for (WorkerBean worker : group.getWorkers()) {
+                            WorkerAction workerAction = WorkerAction.getWorkerAction(worker);
+                            try {
+                                workerAction.getState();
+                            } catch (Exception e) {
+                                String message = e.getClass().getName() + ": " + e.getMessage();
+                                throw new JadortServiceException("Failed getting the state of worker " + worker.getName()
+                                    + ": " + message, e);
+                            }
+                        }
+                    }
+
                     this.operation.setSelectedGroup(group);
                     this.em.flush();
                     return;
@@ -783,15 +807,16 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
      *         the current step. (this method can be called only in the
      *         {@link Step#EXECUTING_MIGRATION},
      *         {@link Step#UNDEPLOY_ERASE_OLD_VERSION},
-     *         {@link Step#EXECUTING_MIGRATION_OSGI}, {@link Step#ERASE_OLD_VERSIONS},
+     *         {@link Step#EXECUTING_MIGRATION_OSGI},
+     *         {@link Step#ERASE_OLD_VERSIONS},
      *         {@link Step#EXECUTING_MAINTENANCE_CLUSTER} and
      *         {@link Step#EXECUTING_MAINTENANCE_NO_CLUSTER} steps)
      */
     public void abortServer(final ServerBean server) throws JadortServiceException {
         synchronized (this) {
             this.refreshOperation();
-            this.checkStep(Step.EXECUTING_MIGRATION, Step.UNDEPLOY_ERASE_OLD_VERSION, Step.EXECUTING_MIGRATION_OSGI,Step.ERASE_OLD_VERSIONS, 
-                Step.EXECUTING_MAINTENANCE_CLUSTER, Step.EXECUTING_MAINTENANCE_NO_CLUSTER);
+            this.checkStep(Step.EXECUTING_MIGRATION, Step.UNDEPLOY_ERASE_OLD_VERSION, Step.EXECUTING_MIGRATION_OSGI,
+                Step.ERASE_OLD_VERSIONS, Step.EXECUTING_MAINTENANCE_CLUSTER, Step.EXECUTING_MAINTENANCE_NO_CLUSTER);
 
             ServerProgressBean serverProgress = this.getServerProgress(server);
             if (!serverProgress.getActionState().equals(ActionState.RUNNING)) {
@@ -815,7 +840,8 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
      *         step. (this method can be called only in the
      *         {@link Step#EXECUTING_MIGRATION},
      *         {@link Step#UNDEPLOY_ERASE_OLD_VERSION},
-     *         {@link Step#EXECUTING_MIGRATION_OSGI}, {@link Step#ERASE_OLD_VERSIONS},
+     *         {@link Step#EXECUTING_MIGRATION_OSGI},
+     *         {@link Step#ERASE_OLD_VERSIONS},
      *         {@link Step#EXECUTING_MAINTENANCE_CLUSTER} and
      *         {@link Step#EXECUTING_MAINTENANCE_NO_CLUSTER} steps)
      *         <li>if the server state is not in error state.
@@ -824,8 +850,9 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
     public void restartServer(final ServerBean server) throws JadortServiceException {
         synchronized (this) {
             this.refreshOperation();
-            this.checkStep(Step.EXECUTING_MIGRATION, Step.UNDEPLOY_ERASE_OLD_VERSION, Step.EXECUTING_MIGRATION_OSGI,Step.ERASE_OLD_VERSIONS,
-                Step.EXECUTING_MAINTENANCE_CLUSTER, Step.EXECUTING_MAINTENANCE_NO_CLUSTER, Step.DESTROY_OLD_VM_HOSTS);
+            this.checkStep(Step.EXECUTING_MIGRATION, Step.UNDEPLOY_ERASE_OLD_VERSION, Step.EXECUTING_MIGRATION_OSGI,
+                Step.ERASE_OLD_VERSIONS, Step.EXECUTING_MAINTENANCE_CLUSTER, Step.EXECUTING_MAINTENANCE_NO_CLUSTER,
+                Step.DESTROY_OLD_VM_HOSTS);
 
             ServerProgressBean serverProgress = this.getServerProgress(server);
             if (!serverProgress.getActionState().equals(ActionState.FINISHED_ERROR)) {
@@ -848,15 +875,17 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
      *         the current step. (this method can be called only in the
      *         {@link Step#EXECUTING_MIGRATION},
      *         {@link Step#UNDEPLOY_ERASE_OLD_VERSION},
-     *         {@link Step#EXECUTING_MIGRATION_OSGI}, {@link Step#ERASE_OLD_VERSIONS},
+     *         {@link Step#EXECUTING_MIGRATION_OSGI},
+     *         {@link Step#ERASE_OLD_VERSIONS},
      *         {@link Step#EXECUTING_MAINTENANCE_CLUSTER} and
      *         {@link Step#EXECUTING_MAINTENANCE_NO_CLUSTER} steps)
      */
     public boolean checkServer(final ServerBean server) throws JadortServiceException {
         synchronized (this) {
             this.refreshOperation();
-            this.checkStep(Step.EXECUTING_MIGRATION, Step.UNDEPLOY_ERASE_OLD_VERSION, Step.EXECUTING_MIGRATION_OSGI,Step.ERASE_OLD_VERSIONS,
-                Step.EXECUTING_MAINTENANCE_CLUSTER, Step.EXECUTING_MAINTENANCE_NO_CLUSTER, Step.DESTROY_OLD_VM_HOSTS);
+            this.checkStep(Step.EXECUTING_MIGRATION, Step.UNDEPLOY_ERASE_OLD_VERSION, Step.EXECUTING_MIGRATION_OSGI,
+                Step.ERASE_OLD_VERSIONS, Step.EXECUTING_MAINTENANCE_CLUSTER, Step.EXECUTING_MAINTENANCE_NO_CLUSTER,
+                Step.DESTROY_OLD_VM_HOSTS);
 
             try {
                 ServerProgressBean serverProgress = this.getServerProgress(server);
@@ -1035,7 +1064,8 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
      *         (this method can be called only in the
      *         {@link Step#EXECUTING_MIGRATION},
      *         {@link Step#UNDEPLOY_ERASE_OLD_VERSION},
-     *         {@link Step#EXECUTING_MIGRATION_OSGI}, {@link Step#ERASE_OLD_VERSIONS},
+     *         {@link Step#EXECUTING_MIGRATION_OSGI},
+     *         {@link Step#ERASE_OLD_VERSIONS},
      *         {@link Step#EXECUTING_MAINTENANCE_CLUSTER} and
      *         {@link Step#EXECUTING_MAINTENANCE_NO_CLUSTER} steps)
      *         <li>if the server state is not in error state.
@@ -1044,8 +1074,8 @@ public class JadortServiceStatefulBean extends StepManager implements IJadortSer
     public void ignoreServer(final ServerBean server) throws JadortServiceException {
         synchronized (this) {
             this.refreshOperation();
-            this.checkStep(Step.EXECUTING_MIGRATION, Step.UNDEPLOY_ERASE_OLD_VERSION, Step.EXECUTING_MIGRATION_OSGI,Step.ERASE_OLD_VERSIONS,
-                Step.EXECUTING_MAINTENANCE_CLUSTER, Step.EXECUTING_MAINTENANCE_NO_CLUSTER);
+            this.checkStep(Step.EXECUTING_MIGRATION, Step.UNDEPLOY_ERASE_OLD_VERSION, Step.EXECUTING_MIGRATION_OSGI,
+                Step.ERASE_OLD_VERSIONS, Step.EXECUTING_MAINTENANCE_CLUSTER, Step.EXECUTING_MAINTENANCE_NO_CLUSTER);
 
             ServerProgressBean serverProgress = this.getServerProgress(server);
 
